==> web-absence-2.0.tar.gz: absence-v2.0/cgi-bin/absence-control.pl <==
#!/usr/bin/perl

# $Id: absence-control.pl 90 2009-07-14 00:13:21Z urban $

use CGI;

$CGI::POST_MAX = 100;
$CGI::DISABLE_UPLOADS = 1;

my $INSTANCE;

BEGIN {
	if ($ENV{QUERY_STRING} =~ /^instance=(\S+)$/) {
		$ENV{INSTANCE_NAME} = $1;
		$INSTANCE = $1;
	}
}

use AbsenceConfig;
use AbsenceDB;
use AbsenceAuthentication;
use AbsenceAuthorization;

my $DEF_CHUNKSIZE	= 6;
my $MAIN_SCRIPT		= AbsenceConfig::fetch('main_script');
my $MANAGE_SCRIPT	= AbsenceConfig::fetch('manage_script');
#my $CONTROL_SCRIPT	= AbsenceConfig::fetch('control_script');
my $TOP				= AbsenceConfig::fetch('data_dir_rel');
my $COLOR_CONTROL	= AbsenceConfig::fetch('wp_control');
my $VERSION			= '1.5';
my $COOKIE_NAME		= 'absence';

if (exists($ENV{INSTANCE_NAME})){
	$MAIN_SCRIPT .= "?instance=$ENV{INSTANCE_NAME}";
	$COOKIE_NAME = "absence-$ENV{INSTANCE_NAME}";
}

my ($month, $year) = (localtime(time))[4,5];
$month++;
$year += 1900;
my $chunksize = $DEF_CHUNKSIZE;

my $q = new CGI;
$q->import_names;
$q->charset('utf-8');

#-----------------------------------------------------------------
# first, authenticate if necessary
#-----------------------------------------------------------------
my $AUTH_UID = AbsenceAuthentication::checkAuthentication($q);

my %cook = $q->cookie($COOKIE_NAME);

if (exists($cook{chunksize})) {
	$chunksize = $cook{chunksize};
}

my $def_group_id = '';
if (exists($cook{group_id})) {
	$def_group_id = $cook{group_id};
}

if (exists($cook{month})) {
	$month = $cook{month};
	$year = $cook{year};
}

print $q->header(),
	$q->start_html(
		-title		=> 'Absence',
		-target		=> 'display',
		-BGCOLOR	=> $COLOR_CONTROL,
	);

if ((AbsenceConfig::fetch('authentication') eq 'yes') &&
	!defined($ENV{REMOTE_USER}))
{
	print "<H3>NOT AUTHENTICATED</H3>\n", $q->end_html;
	exit;
}

print $q->startform(
	-name	=> 'AbsenceControl',
	-action	=> $MAIN_SCRIPT,
	-method => 'POST',
);

#print "AU:$AUTH_USER ";

print "Show";
print $q->popup_menu(
	-name	=> 'chunksize',
	-values	=> [1..15],
	-default=> $chunksize,
);
print "Months. Start with ";
print $q->popup_menu(
	-name	=> 'start_month',
	-values	=> [1..12],
	-default=> $month,
);
print $q->popup_menu(
	-name	=> 'start_year',
	-values	=> [2002..2010],
	-default=> $year,
);
print $q->submit(-value => 'SHOW ME!');
print $q->submit(-name => 'jump',	-value => 'Previous');
print $q->submit(-name => 'jump',	-value => 'Next');
print "Group";
my @groups = AbsenceAuthorization::getReadGroups($AUTH_UID);
my $labref;
my $def;
foreach my $group_id (@groups) {
	$name = AbsenceDB::getGroup($group_id, 'name');
	$labref->{$group_id} = $name;
}
my $js_submit = q[JavaScript:document.AbsenceControl.submit();];

my @sorted = sort {lc($labref->{$a}) cmp lc($labref->{$b})} @groups;
print $q->popup_menu(
	-name		=> 'group_id',
	-values		=> \@sorted,
	-default	=> $def_group_id,
	-labels		=> $labref,
	-onChange	=> $js_submit,
);

my $inst_str;
if (exists($ENV{INSTANCE_NAME})) {
	$inst_str = qq[?instance=$ENV{INSTANCE_NAME}];
}
print qq[&nbsp;&nbsp;<A HREF="$MANAGE_SCRIPT$inst_str">Manage</A><BR>\n];
print $q->endform;
#print "<BR>cookie_name = [$COOKIE_NAME]\n";


print $q->end_html;

==> web-absence-2.1.tar.gz: absence-v2.1/cgi-bin/absence-control.pl <==
#!/usr/bin/perl

#======================================================================
#    This file is part of Absence.
#
#    Absence is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Absence is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Absence.  If not, see <http://www.gnu.org/licenses/>.
#======================================================================

# $Id: absence-control.pl 111 2013-10-20 17:57:24Z urban $

use CGI;

$CGI::POST_MAX = 100;
$CGI::DISABLE_UPLOADS = 1;

my $INSTANCE;

BEGIN {
	if ($ENV{QUERY_STRING} =~ /^instance=(\S+)$/) {
		$ENV{INSTANCE_NAME} = $1;
		$INSTANCE = $1;
	}
}

use AbsenceConfig;
use AbsenceDB;
use AbsenceAuthentication;
use AbsenceAuthorization;

my $DEF_CHUNKSIZE	= 6;
my $MAIN_SCRIPT		= AbsenceConfig::fetch('main_script');
my $MANAGE_SCRIPT	= AbsenceConfig::fetch('manage_script');
#my $CONTROL_SCRIPT	= AbsenceConfig::fetch('control_script');
my $TOP				= AbsenceConfig::fetch('data_dir_rel');
my $COLOR_CONTROL	= AbsenceConfig::fetch('wp_control');
my $VERSION			= '2.0.1';
my $COOKIE_NAME		= 'absence';

if (exists($ENV{INSTANCE_NAME})){
	$MAIN_SCRIPT .= "?instance=$ENV{INSTANCE_NAME}";
	$COOKIE_NAME = "absence-$ENV{INSTANCE_NAME}";
}

my ($month, $year) = (localtime(time))[4,5];
$month++;
$year += 1900;
my $chunksize = $DEF_CHUNKSIZE;

my $q = new CGI;
$q->import_names;
$q->charset('utf-8');

#-----------------------------------------------------------------
# first, authenticate if necessary
#-----------------------------------------------------------------
my $AUTH_UID = AbsenceAuthentication::checkAuthentication($q);

my %cook = $q->cookie($COOKIE_NAME);

if (exists($cook{chunksize})) {
	$chunksize = $cook{chunksize};
}

my $def_group_id = '';
if (exists($cook{group_id})) {
	$def_group_id = $cook{group_id};
}

if (exists($cook{month})) {
	$month = $cook{month};
	$year = $cook{year};
}

print $q->header(),
	$q->start_html(
		-title		=> 'Absence',
		-target		=> 'display',
		-BGCOLOR	=> $COLOR_CONTROL,
	);

if ((AbsenceConfig::fetch('authentication') eq 'yes') &&
	!defined($ENV{REMOTE_USER}))
{
	print "<H3>NOT AUTHENTICATED</H3>\n", $q->end_html;
	exit;
}

print $q->startform(
	-name	=> 'AbsenceControl',
	-action	=> $MAIN_SCRIPT,
	-method => 'POST',
);

#print "AU:$AUTH_USER ";

print "Show";
print $q->popup_menu(
	-name	=> 'chunksize',
	-values	=> [1..15],
	-default=> $chunksize,
);
print "Months. Start with ";
print $q->popup_menu(
	-name	=> 'start_month',
	-values	=> [1..12],
	-default=> $month,
);
print $q->popup_menu(
	-name	=> 'start_year',
	-values	=> [2005..2025],
	-default=> $year,
);
print $q->submit(-value => 'SHOW ME!');
print $q->submit(-name => 'jump',	-value => 'Previous');
print $q->submit(-name => 'jump',	-value => 'Next');
print "Group";
my @groups = AbsenceAuthorization::getReadGroups($AUTH_UID);
my $labref;
my $def;
foreach my $group_id (@groups) {
	$name = AbsenceDB::getGroup($group_id, 'name');
	$labref->{$group_id} = $name;
}
my $js_submit = q[JavaScript:document.AbsenceControl.submit();];

my @sorted = sort {lc($labref->{$a}) cmp lc($labref->{$b})} @groups;
print $q->popup_menu(
	-name		=> 'group_id',
	-values		=> \@sorted,
	-default	=> $def_group_id,
	-labels		=> $labref,
	-onChange	=> $js_submit,
);

my $inst_str;
if (exists($ENV{INSTANCE_NAME})) {
	$inst_str = qq[?instance=$ENV{INSTANCE_NAME}];
}
print qq[&nbsp;&nbsp;<A HREF="$MANAGE_SCRIPT$inst_str">Manage</A><BR>\n];
print $q->endform;
#print "<BR>cookie_name = [$COOKIE_NAME]\n";


print $q->end_html;
